@@ -1,7 +1,7 @@
 # -*- coding: UTF-8 -*-
-import sys
+import sys,os
+from os import  path
 
-sys.path.append('./')
 sys.path.append('../')
 from ctypes import *
 from commFunction import emxArray_real_T,get_data_of_ctypes_
