@@ -1,7 +1,7 @@
 # -*- coding: UTF-8 -*-
 import sys
-sys.path.append('./')
-sys.path.append('../')
+
+
 import ctypes
 from ctypes import *
 
