@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
-import sys
+import sys,os
+from os import  path
 
-sys.path.append('./')
-sys.path.append('../')
 """
 @author: Gabriel Mittag, TU-Berlin
 """
