@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
-import sys
-sys.path.append('./')
-sys.path.append('../')
+import sys,os
+from os import  path
+
+sys.path.append(os.path.dirname(path.dirname(__file__)))
 
 from commFunction import get_rms,make_out_file,get_ave_rms
 import numpy as np
