@@ -32,7 +32,8 @@ def cal_563_mos(degFile):
         mydll = ctypes.windll.LoadLibrary(sys.prefix + '/p563.dll')
     if cur_paltform == 'macOS':
         mydll = CDLL(sys.prefix + '/p563.dylib')
-
+    if cur_paltform == 'Linux':
+        mydll = CDLL(sys.prefix + '/p563.so')
     #buf = create_string_buffer(degFile.encode('gbk'), len(degFile))
     buf = c_char_p(bytes(degFile.encode('utf-8')))
     mydll.NR_MOS(buf,byref(p563))
