@@ -10,7 +10,15 @@ class pesqstruct(Structure):
 
 def cal_pesq(reffile, testfile,samplerate):
     pesqs = pesqstruct()
-    mydll = ctypes.windll.LoadLibrary(sys.prefix + '/PY_PESQ.dll')
+
+    import platform
+    mydll = None
+    cur_paltform = platform.platform().split('-')[0]
+    if cur_paltform == 'Windows':
+        mydll = ctypes.windll.LoadLibrary(sys.prefix + '/PY_PESQ.dll')
+    if cur_paltform == 'macOS':
+        mydll = CDLL(sys.prefix + '/PY_PESQ.dylib')
+
     inputFile = c_char_p(bytes(reffile.encode('utf-8')))#create_unicode_buffer(inFile.encode('utf-8'), len(inFile))
     outputFile = c_char_p(bytes(testfile.encode('utf-8')))#create_unicode_buffer(outFile.encode('utf-8'), len(outFile))
     if samplerate == 8000:
