@@ -1,10 +1,7 @@
 # -*- coding:utf-8 -*-
 import copy
-import sys
-import  os
-from os import path
-sys.path.append('.')
-sys.path.append('./')
+import sys,os
+from os import  path
 sys.path.append('../')
 from commFunction import getip,log_time,global_result,sftp_connect,sftp_put,sftp_disconnect,get_file_path
 import shutil
