@@ -2,8 +2,9 @@
 import copy
 import sys
 import wave
-sys.path.append('./')
-sys.path.append('../')
+import sys,os
+from os import  path
+sys.path.append(os.path.dirname(path.dirname(__file__)))
 from ctypes import *
 from commFunction import emxArray_real_T,get_data_of_ctypes_,write_ctypes_data_2_file_,get_none_data_of_ctypes_
 import  ctypes
