@@ -8,8 +8,8 @@ from .STI.cal_sti import cal_sti
 from .STOI.STOI import *
 from .resample.resampler import resample,restruct
 from .timeAligment.time_align import cal_fine_delay
-from .commFunction import get_data_array,get_file_path,get_max_cc_by_dll
-from .PCC.Pearson_CC import cal_PCC
+from .commFunction import get_data_array,get_file_path,get_rms
+from .PCC.Pearson_CC import cal_PCC,get_max_cc_by_dll
 from .Noise_Suppression.noiseFuction import cal_noise_Supp
 from .SNR_ESTIMATION.MATCH_SIG import match_sig
 from .SNR_ESTIMATION.SNR_MUSIC import cal_snr_music
