@@ -4,7 +4,6 @@ import time
 import wave
 import numpy as np
 
-
 def wav2pcm(wavfile, data_type=np.int16):
     """
     :param wavfile:
@@ -57,20 +56,7 @@ def pcm2wav(pcm_file, channels=1, bits=16, sample_rate=16000):
     return newFileName
 
 
-def get_data_array(filename):
-    """
 
-    """
-    f = wave.open(filename, "rb")
-    # 读取格式信息
-    # 一次性返回所有的WAV文件的格式信息，它返回的是一个组元(tuple)：声道数, 量化位数（byte单位）, 采样频率, 采样点数, 压缩类型, 压缩类型的描述。wave模块只支持非压缩的数据，因此可以忽略最后两个信息
-    params = f.getparams()
-    nchannels, sampwidth, framerate, nframes = params[:4]
-    # 读取波形数据
-    # 读取声音数据，传递一个参数指定需要读取的长度（以取样点为单位）
-    str_data = f.readframes(nframes)
-    f.close()
-    return np.frombuffer(str_data, dtype=np.int16),framerate,nchannels
 
 
 if __name__ == '__main__':
