@@ -1,10 +1,8 @@
 
 import ctypes
-import sys
-import  os
-from os import path
-sys.path.append('./')
-sys.path.append('../')
+import sys,os
+from os import  path
+sys.path.append(os.path.dirname(path.dirname(__file__)))
 import wave
 import  time
 from commFunction import get_data_array,make_out_file
